EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'HelmCharts_CreateOrUpdateChart',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates or updates a chart in a Helm feed.'
GO

IF OBJECT_ID('[HelmCharts_CreateOrUpdateChart]') IS NOT NULL DROP PROCEDURE [HelmCharts_CreateOrUpdateChart]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [HelmCharts_CreateOrUpdateChart]
(
	@Feed_Id INT,
	@Chart_Name VARCHAR(200),
	@Version_Text VARCHAR(200),
	@Cached_Indicator YNINDICATOR = NULL,
	@Published_Date DATETIME = NULL,
	@Chart_Size BIGINT = NULL,
	@SHA256Hash_Bytes BINARY(64) = NULL,
	@ManifestYaml_Bytes VARBINARY(MAX) = NULL
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

		IF EXISTS(SELECT * FROM [HelmCharts]
		                   WITH (UPDLOCK)
		                  WHERE [Feed_Id] = @Feed_Id
		                    AND [Chart_Name] = @Chart_Name
		                    AND [Version_Text] = @Version_Text) BEGIN

			UPDATE [HelmCharts]
			   SET [Cached_Indicator] = COALESCE(@Cached_Indicator, [Cached_Indicator])
			     , [Published_Date] = COALESCE(@Published_Date, [Published_Date])
			     , [Chart_Size] = COALESCE(@Chart_Size, [Chart_Size])
			     , [SHA256Hash_Bytes] = COALESCE(@SHA256Hash_Bytes, [SHA256Hash_Bytes])
			     , [ManifestYaml_Bytes] = COALESCE(@ManifestYaml_Bytes, [ManifestYaml_Bytes])
			 WHERE [Feed_Id] = @Feed_Id
			   AND [Chart_Name] = @Chart_Name
			   AND [Version_Text] = @Version_Text

			EXEC [Events_RaiseEvent] 'PKGMDF', @Feed_Id, 'Package_Name', @Chart_Name, 'Package_Version', @Version_Text

		END ELSE BEGIN

			INSERT INTO [HelmCharts]
			(
				[Feed_Id],
				[Chart_Name],
				[Version_Text],
				[Cached_Indicator],
				[Published_Date],
				[Chart_Size],
				[SHA256Hash_Bytes],
				[ManifestYaml_Bytes],
				[Download_Count]
			)
			VALUES
			(
				@Feed_Id,
				@Chart_Name,
				@Version_Text,
				COALESCE(@Cached_Indicator, 'N'),
				COALESCE(@Published_Date, GETUTCDATE()),
				@Chart_Size,
				@SHA256Hash_Bytes,
				@ManifestYaml_Bytes,
				0
			)

			EXEC [Events_RaiseEvent] 'PKGADD', @Feed_Id, 'Package_Name', @Chart_Name, 'Package_Version', @Version_Text

		END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [HelmCharts_CreateOrUpdateChart] TO [ProGetUser_Role]
GO
