EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'VulnerabilitySources_CreateOrUpdateVulnerabilitySource',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'VulnerabilitySource_Id',
    /* Description_Text        */ 'Creates a new vulnerability source or edits an existing one.'
GO

IF OBJECT_ID('[VulnerabilitySources_CreateOrUpdateVulnerabilitySource]') IS NOT NULL DROP PROCEDURE [VulnerabilitySources_CreateOrUpdateVulnerabilitySource]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [VulnerabilitySources_CreateOrUpdateVulnerabilitySource]
(
	@VulnerabilitySource_Name VARCHAR(50),
	@Configuration_Xml XML,
	@VulnerabilitySource_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF @VulnerabilitySource_Id IS NULL
	BEGIN

		INSERT INTO [VulnerabilitySources]
		(
			[VulnerabilitySource_Name],
			[Configuration_Xml]
		)
		VALUES
		(
			@VulnerabilitySource_Name,
			@Configuration_Xml
		)

		SET @VulnerabilitySource_Id = SCOPE_IDENTITY()

	END
	ELSE
	BEGIN

		UPDATE [VulnerabilitySources]
		   SET [VulnerabilitySource_Name] = @VulnerabilitySource_Name,
		       [Configuration_Xml] = @Configuration_Xml
		 WHERE [VulnerabilitySource_Id] = @VulnerabilitySource_Id

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [VulnerabilitySources_CreateOrUpdateVulnerabilitySource] TO [ProGetUser_Role]
GO